
library("MASS")
library("MuMIn")
options(na.action = "na.fail")

#setwd("~/Dropbox/Draft_PaperIII/regression_ASE")
#data <- read.csv("ASE_regression_matrix_Steige_et_al_2016.csv")
data <- read.csv("https://ndownloader.figshare.com/files/6924998?private_link=793a2b074842c5d2ff6a")
head(data)

dim(data)

data1 <- data  [complete.cases(data), ]
table(data1$ASE)

#center and scale the data
dd2 <- as.data.frame(apply(data1,2, scale) )

#we want to have the response as binary
dd2$ASE <- as.factor(data1$ASE)
#we also want CNS and TE as binary
dd2$TE_pop <- as.factor(data1$TE_pop)
dd2$alpha <- as.factor(data1$alpha)
dd2$betagamma <- as.factor(data1$betagamma)
dd2$consgbm <- as.factor(data1$consgbm)

summary(dd2)

glm.full_pop_TE <- glm(ASE ~ ., family="binomial", data=dd2)
summary(glm.full_pop_TE)
#odd ratio
exp(coef(glm.full_pop_TE))

sel_glm_pop_TE <- stepAIC(glm.full_pop_TE, direction ="both", trace=F, k=2, steps=10000)
summary(sel_glm_pop_TE)
barplot((sort(exp(coef(sel_glm_pop_TE))) - 1)[-1], las = 2)


sel_glm_pop_TE_BIC <- stepAIC(glm.full_pop_TE, direction ="both", trace=F, k= log(nrow(dd2)), steps=10000)
summary(sel_glm_pop_TE_BIC)
barplot((sort(exp(coef(sel_glm_pop_TE_BIC)))-1)[-1], las = 2)

#create a temp file to save an image file
rd_num  <- round(runif(1, 10000 , 30000))
tpfile <- paste0("tempfile_", rd_num , ".RData")
#tpfile  <- "tempfile_23158.RData"

if(file.exists(tpfile)){
    load(tpfile)
}else{
    dGLM <- dredge(glm.full_pop_TE, trace = 2, extra = "adjR^2")
}
#this take some times ~20 min so we will save an image to avoid doing it again

#this take some times ~20 min so we will save an image to avoid doing it again
save.image(file = tpfile)

dGLMavg <- model.avg(dGLM)

summary(dGLMavg, abbrev.names = F)

importance(dGLMavg)

plot(dGLM, col = c("green", "blue"), col2="grey", border="white")

barplot(exp(coef(dGLM))[,-1], las = 2)

# if(file.exists(tpfile)){
#     load(tpfile)
# }else{
#     dGLM_BIC <- dredge(glm.full_pop_TE, rank = "BIC", trace = 2, extra = "adjR^2")
# }

    dGLM_BIC <- dredge(glm.full_pop_TE, rank = "BIC", trace = 2, extra = "adjR^2")



#this takes some times ~20 min so we will save an image to avoid doing it again
save.image(file = tpfile)

dGLM_BIC_avg <- model.avg(dGLM_BIC)

summary(dGLM_BIC_avg, abbrev.names = F)

importance(dGLM_BIC_avg)

plot(dGLM_BIC, col = c("green", "blue"), col2="grey", border="white")

barplot(exp(coef(dGLM_BIC))[,-1], las = 2)

library(pls)

dd2$ASE  <- as.numeric(dd2$ASE)
g <- pcr( ASE ~ recrates + tau + Glength + ln_expr_level +  Gdens + dS + pi500up + piNpiS  +coex, data=dd2, y=T)

summary(g)

g$loadings

pretty(g$coefficients)

biplot(g, var.axes = TRUE, pch =20)

explvar(g)

explvar <- explvar(g)/100
variance <- rbind(explvar, g$loadings[,1:9])
variance

library(RColorBrewer)
mypalette=brewer.pal(n=10, name="Paired")
mypalette2=c("grey", mypalette)

#get table of percentage of components
tab_1 <- abs(g$loadings[,1:9])

dataframe_Comp <- tab_1[,1]/sum(tab_1[,1])*100
dataframe_Comp <- cbind(dataframe_Comp,(tab_1[,2]/sum(tab_1[,2])*100))
dataframe_Comp <- cbind(dataframe_Comp,(tab_1[,3]/sum(tab_1[,3])*100))
dataframe_Comp <- cbind(dataframe_Comp,(tab_1[,4]/sum(tab_1[,4])*100))
dataframe_Comp <- cbind(dataframe_Comp,(tab_1[,5]/sum(tab_1[,5])*100))
dataframe_Comp <- cbind(dataframe_Comp,(tab_1[,6]/sum(tab_1[,6])*100))
dataframe_Comp <- cbind(dataframe_Comp,(tab_1[,7]/sum(tab_1[,7])*100))
dataframe_Comp <- cbind(dataframe_Comp,(tab_1[,8]/sum(tab_1[,8])*100))
dataframe_Comp <- cbind(dataframe_Comp,(tab_1[,9]/sum(tab_1[,9])*100))


colnames(dataframe_Comp) <- c("Comp1", "Comp2", "Comp3", "Comp4", "Comp5", "Comp6", "Comp7", "Comp8", "Comp9")
rownames(dataframe_Comp) <- c("recrates", "tau", "Glength", "ln_expr_level", "Gdens", "dS", "pi500up", "piNpiS", "coex")

dataframe_Comp



# write.table(dataframe_Comp, file="pct_contribution_of_each_variable_to_PCs.txt",sep="\t",col.names=T)
#generate data for regression
dd4 <- NULL
dd4$ASE <- as.factor(g$y[,1])
dd4$Comp1 <- g$score[,1]
dd4$Comp2 <- g$score[,2]
dd4$Comp3 <- g$score[,3]
dd4$Comp4 <- g$score[,4]
dd4$Comp5 <- g$score[,5]
dd4$Comp6 <- g$score[,6]
dd4$Comp7 <- g$score[,7]
dd4$Comp8 <- g$score[,8]
dd4$Comp9 <- g$score[,9]

dd4$TE_pop <- dd2$TE_pop
dd4$alpha <- dd2$alpha
dd4$betagamma <- dd2$betagamma
dd4$consgbm <- dd2$consgbm
dd4  <- as.data.frame(dd4)
str(dd4)


glm.full_comp <- glm(ASE ~ . , family="binomial", data=dd4)
summary(glm.full_comp)

pretty(exp(coef(glm.full_comp)))

sel_glm_comp_AIC <- stepAIC(glm.full_comp, direction ="both", trace=0, k=2, steps=10000)
summary(sel_glm_comp_AIC)



sel_glm_comp_BIC <- stepAIC(glm.full_comp, direction ="both", trace=0, k=log(nrow(dd4)), steps=10000)
summary(sel_glm_comp_BIC)

pretty(residuals(sel_glm_comp_BIC))

barplot(sort(exp(coef(sel_glm_comp_BIC))), las = 2)
